@@ -4,11 +4,11 @@
 
 =head1 NAME
 
-Locale::Po4a::Man - Convert manual pages from/to PO files
+Locale::Po4a::Man - convert manual pages from/to PO files
 
 =head1 DESCRIPTION
 
-The po4a (po for anything) project goal is to ease translations (and more
+The po4a (PO for anything) project goal is to ease translations (and more
 interestingly, the maintenance of translations) using gettext tools on
 areas where they were not expected like documentation.
 
@@ -28,10 +28,7 @@ that translators can't mess up with them.
 Unindented paragraphs are automatically rewrapped for the translator.  This
 can lead to some minor difference in the generated output, since the
 rewrapping rules used by groff aren't very clear. For example, two spaces
-after a parenthesis are sometimes preserved, while typographic rules only
-ask to preserve the two spaces after the period sign (ok, I'm not native
-speaker, and I'm not sure of that. If you have any other information,
-you're welcome). 
+after a parenthesis are sometimes preserved.
 
 Anyway, the difference will only be about the position of the extra spaces
 in wrapped paragraph, and I think it's worth.
@@ -41,7 +38,7 @@ in wrapped paragraph, and I think it's worth.
 The first change is about font change specifications.  In nroff, there are
 several ways to specify if a given word should be written in small, bold or
 italics. In the text to translate, there is only one way, borrowed from the
-pod (perl online documentation) format:
+POD (Perl online documentation) format:
 
 =over
 
@@ -103,7 +100,7 @@ character (i.e., using `\&` or '\&' respectively).
 
 Since these chars are used to delimit parts under font modification, you
 can't use them verbatim. Use EE<lt>ltE<gt> and EE<lt>gtE<gt> instead (as in
-pod, one more time).
+POD, one more time).
 
 =head1 OPTIONS ACCEPTED BY THIS MODULE
 
@@ -326,15 +323,15 @@ it's valid in nroff, but would complicate too much the parser to be
 handled.
 
 Of course, another possibility is to use another format, more translator
-friendly (like pod using po4a::pod, or one of the xml familly like sgml),
+friendly (like POD using po4a::pod, or one of the XML familly like SGML),
 but thanks to po4a::man it isn't needed anymore. That being said, if the
-source format of your documentation is pod, or xml, it may be clever to
+source format of your documentation is POD, or XML, it may be clever to
 translate the source format and not this generated one. In most cases,
 po4a::man will detect generated pages and issue a warning. It will even
-refuse to process Pod generated pages, because those pages are perfectly
+refuse to process POD generated pages, because those pages are perfectly
 handled by po4a::pod, and because their nroff counterpart defines a lot of
 new macros I didn't want to write support for. On my box, 1432 of the 4323
-pages are generated from pod and will be ignored by po4a::man.
+pages are generated from POD and will be ignored by po4a::man.
 
 In most cases, po4a::man will detect the problem and refuse to process the
 page, issuing an adapted message. In some rare cases, the program will
@@ -353,7 +350,7 @@ Some tests are regularly run on Linux boxes:
 =item *
 
 one third of the pages are refused because they were generated from
-another format supported by po4a (e.g. pod or SGML).
+another format supported by po4a (e.g. POD or SGML).
 
 =item *
 
@@ -653,7 +650,7 @@ NEW_LINE:
         unless ($allow_generated) {
                 # Check for comments indicating that the file was generated.
                 if ($c =~ /Pod::Man/) {
-                    warn wrap_ref_mod($ref, "po4a::man", dgettext("po4a", "This file was generated with Pod::Man. Translate the pod file with the pod module of po4a."));
+                    warn wrap_ref_mod($ref, "po4a::man", dgettext("po4a", "This file was generated with Pod::Man. Translate the POD file with the pod module of po4a."));
                     exit 254;
                 } elsif ($c =~ /generated by help2man/)    {
                     warn wrap_ref_mod($ref, "po4a::man", dgettext("po4a", "This file was generated with help2man. Translate the source file with the regular gettext."));
@@ -709,7 +706,7 @@ NEW_LINE:
         @next_comments = ();
     }
 
-    # A .I or .B request chnage the current font
+    # A .I or .B request change the current font
     # and on exit, switch the font to Roman
     # When one of these request doesn't have its argument on its line
     # (and when we support this usage), we must keep this font request to
@@ -1065,7 +1062,7 @@ sub post_trans {
     $str =~ s/\Q$nbs_out/\\ /sg if defined $nbs_out;
     # No nbsp (said "\ " in groff on the last pos of the line, or groff adds
     # an extra space
-    $str =~ s/\\ \n/\\ /sg;
+    $str =~ s/\\ \n(?=.)/\\ /sg;
 
     # Make sure we compute internal sequences right.
     # think about: B<AZE E<lt> EZA E<gt>>
@@ -1158,7 +1155,7 @@ sub post_trans {
         $str = $tmp.$str;
     }
     if (not defined $self->{type}) {
-        $str =~ s/ $//mg;
+        $str =~ s/(?<!\\) $//mg;
     }
 
     print STDERR "$str\n" if ($debug{'postrans'});
@@ -1216,7 +1213,14 @@ sub t {
 # As a rule of thumb, I do not recode macro names, unless they may be
 # followed by other characters.
 sub r {
-    return $_[0]->recode_skipped_text($_[1]);
+    my $self = shift;
+    my $str  = shift;
+
+    # non-breaking spaces
+    # some non-breaking spaces may have been added during the parsing
+    $str =~ s/\Q$nbs/\\ /sg;
+
+    return $self->recode_skipped_text($str);
 }
 
 
@@ -1772,8 +1776,8 @@ sub noarg {
 
 # For macro whose arguments shouldn't be translated
 sub untranslated {
-    my $self = shift;
-    $self->pushmacro(@_);
+    my ($self,$first)= (shift,0);
+    $self->pushmacro( map { $first++ ?$self->r($_):$_ } @_);
 }
 
 ###
