@@ -21,13 +21,15 @@
 #
 ########################################################################
 
+=encoding UTF-8
+
 =head1 NAME
 
-Locale::Po4a::Texinfo - Convert Texinfo documents and derivates from/to PO files
+Locale::Po4a::Texinfo - convert Texinfo documents and derivates from/to PO files
 
 =head1 DESCRIPTION
 
-The po4a (po for anything) project goal is to ease translations (and more
+The po4a (PO for anything) project goal is to ease translations (and more
 interestingly, the maintenance of translations) using gettext tools on
 areas where they were not expected like documentation.
 
@@ -265,6 +267,20 @@ sub line_command {
     return ($translated,@$env);
 }
 
+sub defindex_line_command {
+    my $self = shift;
+    my ($command,$variant,$args,$env) = (shift,shift,shift,shift);
+    my $no_wrap = shift;
+    print "line_command($command,$variant,@$args,@$env,$no_wrap)="
+        if ($debug{'commands'});
+    my $idx = $$args[1]."index";
+    $commands{$idx} = \&line_command;
+    $break_line{$idx} = 1;
+    $translate_line_command{$idx} = 1;
+
+    return line_command($self,$command,$variant,$args,$env,$no_wrap);
+}
+
 sub translate_buffer_menu {
     my ($self,$buffer,$no_wrap,@env) = (shift,shift,shift,@_);
     print STDERR "translate_buffer_menu($buffer,$no_wrap,@env)="
@@ -342,7 +358,7 @@ sub translate_buffer_ignore {
 }
 $translate_buffer_env{"ignore"} = \&translate_buffer_ignore;
 
-foreach (qw(appendix section cindex findex kindex pindex vindex subsection
+foreach (qw(appendix section cindex findex kindex opindex pindex vindex subsection
             dircategory subtitle include
             exdent center unnumberedsec
             heading unnumbered unnumberedsubsec
@@ -355,12 +371,16 @@ foreach (qw(appendix section cindex findex kindex pindex vindex subsection
     $break_line{$_} = 1;
     $translate_line_command{$_} = 1;
 }
-foreach (qw(c comment set setfilename setchapternewpage vskip synindex
+foreach (qw(c comment clear set setfilename setchapternewpage vskip synindex
             syncodeindex need fonttextsize printindex headings finalout sp
-            defcodeindex defindex definfoenclose)) {
+            definfoenclose)) {
     $commands{$_} = \&line_command;
     $break_line{$_} = 1;
 }
+foreach (qw(defcodeindex defindex)) {
+    $commands{$_} = \&defindex_line_command;
+    $break_line{$_} = 1;
+}
 # definfoenclose: command definition => translate?
 foreach (qw(insertcopying page bye summarycontents shortcontents contents
             noindent)) {
@@ -392,9 +412,9 @@ foreach (qw(defcvx deffnx defivarx defmacx defmethodx defopx defoptx
 foreach (qw(titlefont w i r b sansserif sc slanted strong t cite email
             footnote indicateurl emph ref xref pxref inforef kbd key
             acronym),
-# The following commands could cause problems since the their arguments
-# has a semantic and a translator could decide not to translate code but
-# still translate thses short words if they appear in another context.
+# The following commands could cause problems since their arguments
+# have a semantic and a translator could decide not to translate code but
+# still translate theses short words if they appear in another context.
          qw(file command dfn dmn option math code samp var)) {
     register_generic_command("-$_,{_}");
 }
