@@ -32,11 +32,11 @@
 
 =head1 NAME
 
-Locale::Po4a::Xml - Convert XML documents and derivates from/to PO files
+Locale::Po4a::Xml - convert XML documents and derivates from/to PO files
 
 =head1 DESCRIPTION
 
-The po4a (po for anything) project goal is to ease translations (and more
+The po4a (PO for anything) project goal is to ease translations (and more
 interestingly, the maintenance of translations) using gettext tools on
 areas where they were not expected like documentation.
 
@@ -70,6 +70,7 @@ my @path;
 my %entities;
 
 my @comments;
+my %translate_options_cache;
 
 my $_shiftline_in_comment = 0;
 sub shiftline {
@@ -231,7 +232,7 @@ written in most XML based documents.
 There are some options (described in the next section) that can customize
 this behavior.  If this doesn't fit to your document format you're encouraged
 to write your own module derived from this, to describe your format's details.
-See the section "Writing derivate modules" below, for the process description.
+See the section B<WRITING DERIVATE MODULES> below, for the process description.
 
 =cut
 
@@ -287,7 +288,7 @@ documents.
 =item B<ontagerror>
 
 This option defines the behavior of the module when it encounter a invalid
-Xml syntax (a closing tag which does not match the last opening tag, or a
+XML syntax (a closing tag which does not match the last opening tag, or a
 tag's attribute without value).
 It can take the following values:
 
@@ -553,6 +554,9 @@ sub initialize {
 	$self->{nodefault}=();
 
 	$self->treat_options;
+
+	#  Clear cache
+	%translate_options_cache=();
 }
 
 =head1 WRITING DERIVATE MODULES
@@ -664,15 +668,15 @@ define a tag type you'll have to make a hash with the following keys:
 
 =over 4
 
-=item beginning
+=item B<beginning>
 
 Specifies the beginning of the tag, after the "E<lt>".
 
-=item end
+=item B<end>
 
 Specifies the end of the tag, before the "E<gt>".
 
-=item breaking
+=item B<breaking>
 
 It says if this is a breaking tag class.  A non-breaking (inline) tag is one
 that can be taken as part of the content of another tag.  It can take the
@@ -680,12 +684,12 @@ values false (0), true (1) or undefined.  If you leave this undefined, you'll
 have to define the f_breaking function that will say whether a concrete tag of
 this class is a breaking tag or not.
 
-=item f_breaking
+=item B<f_breaking>
 
 It's a function that will tell if the next tag is a breaking one or not.  It
-should be defined if the "breaking" option is not.
+should be defined if the B<breaking> option is not.
 
-=item f_extract
+=item B<f_extract>
 
 If you leave this key undefined, the generic extraction function will have to
 extract the tag itself.  It's useful for tags that can have other tags or
@@ -693,7 +697,7 @@ special structures in them, so that the main parser doesn't get mad.  This
 function receives a boolean that says if the tag should be removed from the
 input stream or not.
 
-=item f_translate
+=item B<f_translate>
 
 This function receives the tag (in the get_string_until() format) and returns
 the translated tag (translated attributes or all needed transformations) as a
@@ -730,7 +734,7 @@ our @tag_types = (
 		f_extract	=> \&tag_extract_doctype,
 		f_translate	=> \&tag_trans_doctype},
 	{	beginning	=> "![CDATA[",
-		end		=> "",
+		end		=> "]]",
 		breaking	=> 1,
 		f_extract	=> \&CDATA_extract,
 		f_translate	=> \&CDATA_trans},
@@ -1266,7 +1270,6 @@ sub treat_attributes {
 #   n: a custom tag
 #
 # A translatable inline tag in an untranslated tag is treated as a translatable breaking tag.
-my %translate_options_cache;
 sub get_translate_options {
 	my $self = shift;
 	my $path = shift;
@@ -1916,15 +1919,15 @@ The valid options are:
 
 =over 4
 
-=item include
+=item B<include>
 
 This makes the returned array to contain the searched text
 
-=item remove
+=item B<remove>
 
 This removes the returned stream from the input
 
-=item unquoted
+=item B<unquoted>
 
 This ensures that the searched text is outside any quotes
 
